Module coding

Module coding 

Contains encoding and decoding helpers.

Structs

BoundsExceeded
The number is too large to fit in a VarInt (62 bits).
Reader
A reader for decoding messages from a stream.
Sizer
A BufMut implementation that only counts the size of the buffer.
Stream
A Writer and Reader pair for a single stream.
VarInt
An integer less than 2^62
Version
A version number negotiated during the setup.
Versions
A list of versions in preferred order.
Writer
A wrapper around a web_transport_trait::SendStream that will reset on Drop.

Enums

DecodeError
A decode error.
EncodeError
An error that occurs during encoding.

Traits

Decode
Read the from the buffer using the given version.
Encode
Write the value to the buffer using the given version.