#[non_exhaustive]pub enum Error {
Show 25 variants
Transport(String),
Decode(DecodeError),
Version,
RequiredExtension,
UnexpectedStream,
BoundsExceeded(BoundsExceeded),
Duplicate,
Cancel,
Timeout,
Old,
App(u16),
NotFound,
WrongSize,
ProtocolViolation,
Unauthorized,
UnexpectedMessage,
Unsupported,
Encode(EncodeError),
TooManyParameters,
InvalidRole,
UnknownAlpn(String),
Dropped,
Closed,
CacheFull,
Remote(u32),
}Expand description
A list of possible errors that can occur during the session.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Transport(String)
Decode(DecodeError)
Version
RequiredExtension
A required extension was not present
UnexpectedStream
An unexpected stream type was received
BoundsExceeded(BoundsExceeded)
Duplicate
A duplicate ID was used
Cancel
Timeout
It took too long to open or transmit a stream.
Old
The group is older than the latest group and dropped.
App(u16)
NotFound
WrongSize
ProtocolViolation
UnexpectedMessage
Unsupported
Encode(EncodeError)
TooManyParameters
InvalidRole
UnknownAlpn(String)
Dropped
Closed
CacheFull
The cached frame has been evicted due to the group size limit.
Remote(u32)
A remote error received via a stream/session reset code.
Implementations