pub struct BandwidthProducer { /* private fields */ }Expand description
Produces bandwidth estimates, notifying consumers when the value changes.
Implementations
Sourceimpl BandwidthProducer
impl BandwidthProducer
Sourcepub fn new() -> BandwidthProducer
pub fn new() -> BandwidthProducer
Create a fresh producer with no current estimate.
Sourcepub fn set(&self, bitrate: Option<u64>) -> Result<(), Error>
pub fn set(&self, bitrate: Option<u64>) -> Result<(), Error>
Set the current bandwidth estimate in bits per second.
Sourcepub fn consume(&self) -> BandwidthConsumer
pub fn consume(&self) -> BandwidthConsumer
Create a new consumer for the bandwidth estimate.