pub struct GroupConsumer {
pub info: Group,
/* private fields */
}Expand description
Consume a group, frame-by-frame.
Fields
info: GroupImplementations
Sourceimpl GroupConsumer
impl GroupConsumer
Sourcepub async fn read_frame(&mut self) -> Result<Option<Bytes>>
pub async fn read_frame(&mut self) -> Result<Option<Bytes>>
Read the next frame’s data all at once.
Cancel-safe: if cancelled after obtaining the frame but before reading, we retry from the same index and create a fresh consumer.
Sourcepub async fn get_frame(&self, index: usize) -> Result<Option<FrameConsumer>>
pub async fn get_frame(&self, index: usize) -> Result<Option<FrameConsumer>>
Block until the frame at the given index is available.
Returns None if the group is finished and the index is out of range.
Sourcepub async fn next_frame(&mut self) -> Result<Option<FrameConsumer>>
pub async fn next_frame(&mut self) -> Result<Option<FrameConsumer>>
Return a consumer for the next frame for chunked reading.