pub struct Session { /* private fields */ }Expand description
A MoQ transport session, wrapping a WebTransport connection.
Created via:
crate::Client::connectfor clients.crate::Server::acceptfor servers.
Implementations
Sourceimpl Session
impl Session
Sourcepub fn send_bandwidth(&self) -> Option<BandwidthConsumer>
pub fn send_bandwidth(&self) -> Option<BandwidthConsumer>
Returns a consumer for the estimated send bitrate (from the congestion controller).
Returns None if the QUIC backend doesn’t support bandwidth estimation.
Sourcepub fn recv_bandwidth(&self) -> Option<BandwidthConsumer>
pub fn recv_bandwidth(&self) -> Option<BandwidthConsumer>
Returns a consumer for the estimated receive bitrate (from PROBE).
Returns None if the MoQ version doesn’t support PROBE (requires moq-lite-03+).