pub struct BandwidthProducer { /* private fields */ }Expand description
Produces bandwidth estimates, notifying consumers when the value changes.
Implementations
Sourceimpl BandwidthProducer
impl BandwidthProducer
pub fn new() -> Self
Sourcepub fn set(&self, bitrate: Option<u64>) -> Result<()>
pub fn set(&self, bitrate: Option<u64>) -> Result<()>
Set the current bandwidth estimate in bits per second.
Sourcepub fn consume(&self) -> BandwidthConsumer
pub fn consume(&self) -> BandwidthConsumer
Create a new consumer for the bandwidth estimate.