pub struct BroadcastDynamic { /* private fields */ }Expand description
Handles on-demand track creation for a broadcast.
When a consumer requests a track that doesn’t exist, a TrackProducer is created and queued for the dynamic producer to fulfill via Self::requested_track. Dropped when no longer needed; pending requests are automatically aborted.
Implementations
Sourceimpl BroadcastDynamic
impl BroadcastDynamic
Sourcepub async fn requested_track(&mut self) -> Result<Option<TrackProducer>, Error>
pub async fn requested_track(&mut self) -> Result<Option<TrackProducer>, Error>
Block until a consumer requests a track, returning its producer.
Sourcepub fn consume(&self) -> BroadcastConsumer
pub fn consume(&self) -> BroadcastConsumer
Create a consumer that can subscribe to tracks in this broadcast.